@@ -221,12 +221,14 @@ var NAVTREE =
       [ "\\endinternal", "commands.html#cmdendinternal", null ],
       [ "\\extends <name>", "commands.html#cmdextends", null ],
       [ "\\file [<name>]", "commands.html#cmdfile", null ],
+      [ "\\fileinfo['{'option'}']", "commands.html#cmdfileinfo", null ],
+      [ "\\lineinfo", "commands.html#cmdlineinfo", null ],
       [ "\\fn (function declaration)", "commands.html#cmdfn", null ],
       [ "\\headerfile <header-file> [<header-name>]", "commands.html#cmdheaderfile", null ],
       [ "\\hideinitializer", "commands.html#cmdhideinitializer", null ],
       [ "\\idlexcept <name>", "commands.html#cmdidlexcept", null ],
       [ "\\implements <name>", "commands.html#cmdimplements", null ],
-      [ "\\ingroup (<groupname> [<groupname> <groupname>])", "commands.html#cmdingroup", null ],
+      [ "\\ingroup (<groupname> [<groupname>]*)", "commands.html#cmdingroup", null ],
       [ "\\interface <name> [<header-file>] [<header-name>]", "commands.html#cmdinterface", null ],
       [ "\\internal", "commands.html#cmdinternal", null ],
       [ "\\mainpage [(title)]", "commands.html#cmdmainpage", null ],
@@ -266,6 +268,7 @@ var NAVTREE =
       [ "\\cond [(section-label)]", "commands.html#cmdcond", null ],
       [ "\\copyright { copyright description }", "commands.html#cmdcopyright", null ],
       [ "\\date { date description }", "commands.html#cmddate", null ],
+      [ "\\showdate \"<format>\" [ <date_time> ]", "commands.html#cmdshowdate", null ],
       [ "\\deprecated { description }", "commands.html#cmddeprecated", null ],
       [ "\\details { detailed description }", "commands.html#cmddetails", null ],
       [ "\\noop ( text to be ignored )", "commands.html#cmdnoop", null ],
@@ -399,7 +402,10 @@ var NAVTREE =
       [ "\\--", "commands.html#cmdndash", null ],
       [ "\\---", "commands.html#cmdmdash", null ]
     ] ],
-    [ "HTML Commands", "htmlcmds.html", null ],
+    [ "HTML Commands", "htmlcmds.html", [
+      [ "HTML tag commands", "htmlcmds.html#htmltagcmds", null ],
+      [ "HTML4 character entities", "htmlcmds.html#htmlentities", null ]
+    ] ],
     [ "XML Commands", "xmlcmds.html", null ],
     [ "Emoji support", "emojisup.html", [
       [ "Representation", "emojisup.html#emojirep", null ],
@@ -418,6 +424,7 @@ var NAVTREE =
     [ "Doxygen's Internals", "arch.html", null ],
     [ "Changelog", "changelog.html", [
       [ "1.9 Series", "changelog.html#log_1_9", [
+        [ "Release 1.9.5", "changelog.html#log_1_9_5", null ],
         [ "Release 1.9.4", "changelog.html#log_1_9_4", null ],
         [ "Release 1.9.3", "changelog.html#log_1_9_3", null ],
         [ "Release 1.9.2", "changelog.html#log_1_9_2", null ],
@@ -465,7 +472,7 @@ var NAVTREE =
 var NAVTREEINDEX =
 [
 "arch.html",
-"config.html#config_docbook"
+"commands.html#cmdxrefitem"
 ];
 
 var SYNCONMSG = 'click to disable panel synchronisation';
