@@ -1,5 +1,9 @@
 var NAVTREEINDEX1 =
 {
+"commands.html#cmdxrefitem":[22,105],
+"config.html":[21],
+"config.html#config_autogen":[21,13],
+"config.html#config_build":[21,2],
 "config.html#config_docbook":[21,12],
 "config.html#config_dot":[21,18],
 "config.html#config_examples":[21,19],
@@ -98,6 +102,8 @@ var NAVTREEINDEX1 =
 "grouping.html#modules":[5,0],
 "grouping.html#subpaging":[5,2],
 "htmlcmds.html":[23],
+"htmlcmds.html#htmlentities":[23,1],
+"htmlcmds.html#htmltagcmds":[23,0],
 "index.html":[],
 "install.html":[0],
 "install.html#install_bin_unix":[0,1],
